@@ -18,7 +18,7 @@ use crate::utils::latest_cli_version;
 // released one, then run `./target/debug/dprint upgrade --verbose`.
 
 pub async fn upgrade<TEnvironment: Environment>(environment: &TEnvironment) -> Result<()> {
-  let latest_version = latest_cli_version(environment).context("Error fetching latest CLI verison.")?;
+  let latest_version = latest_cli_version(environment).context("Error fetching latest CLI version.")?;
   let current_version = environment.cli_version();
   if current_version == latest_version {
     environment.log(&format!("Already on latest version {}", latest_version));
@@ -50,6 +50,7 @@ pub async fn upgrade<TEnvironment: Environment>(environment: &TEnvironment) -> R
   let os = environment.os();
   let zip_suffix = match os.as_str() {
     "linux" => "unknown-linux-gnu",
+    "linux-musl" => "unknown-linux-musl",
     "macos" => "apple-darwin",
     "windows" => "pc-windows-msvc",
     _ => bail!("Not implemented operating system: {}", os),
